@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20250220';
+our $VERSION = '5.20250414';
 our %utilities;
 
 sub utilities {
@@ -2105,6 +2105,27 @@ my %delta = (
         removed => {
         }
     },
+    5.041010 => {
+        delta_from => 5.041009,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.038004 => {
+        delta_from => 5.038003,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.040002 => {
+        delta_from => 5.040001,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
